/* Argument checker for chgrp */
#include <string.h>
#include <unistd.h>
#include <stdlib.h>

char *progname = "chgrp";

/*D

  ptchgrp - SUT chgrp

Description:

ptchgrp changes the group of a list of files on specified hosts.

Command Line Arguments:

ptchgrp [-m <machine_file>|-M <machine_list>] [-Rfh] group <file1> [<file2> <file3>...]

.N machine_args

. -R - change group ownership recursively
. -f - suppress error messages
. -h - change the group ownership of symbolic links instead of the files to which they point
. group - the groupname of the new group of the files
- <file1> [<file2> <file3>...] - the list of files to regroup

Environment Variables:

.N machine_envs

Examples:

To change the group of a file "myfile" to users on the machines
specified in the file "destination_machines" use

.vb
ptchgrp -m destination_machines users myfile
.ve

To make the same change, specifying the machines on the command line, use

.vb
ptchgrp -M "host1 host2 host3" users myfile
.ve

To change the group of all files and directories starting with 'u' in directory 
"/home/johndoe/project" to users, use

.vb
ptchgrp -m destination_machines -R users "/home/johndoe/project/u*"
.ve

.seealso chgrp(1)

D*/
int check_args(int argc, char *argv[])
{
    int c;

    while ((c = getopt(argc, argv, "fhR")) != -1) {
        switch (c) {
            case 'f':
            case 'h':
            case 'R':
                continue;
            default:
                return -1;
        }
    }

    if (argc - optind < 2)
        return -1;

    return 0;
}
